@@ -152,15 +152,13 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (UhmServer, uhm_server, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (UhmServer, uhm_server, G_TYPE_OBJECT)
 
 static void
 uhm_server_class_init (UhmServerClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (UhmServerPrivate));
-
 	gobject_class->get_property = uhm_server_get_property;
 	gobject_class->set_property = uhm_server_set_property;
 	gobject_class->dispose = uhm_server_dispose;
@@ -335,7 +333,7 @@ uhm_server_class_init (UhmServerClass *klass)
 static void
 uhm_server_init (UhmServer *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, UHM_TYPE_SERVER, UhmServerPrivate);
+	self->priv = uhm_server_get_instance_private (self);
 }
 
 static void
@@ -2289,6 +2287,14 @@ done:
 	return retval;
 }
 
+static void
+parameter_names_closure_notify (gpointer  data,
+                                GClosure *closure)
+{
+	gchar **parameter_names = data;
+	g_strfreev (parameter_names);
+}
+
 /**
  * uhm_server_filter_ignore_parameter_values:
  * @self: a #UhmServer
@@ -2323,7 +2329,7 @@ uhm_server_filter_ignore_parameter_values (UhmServer *self,
 	return g_signal_connect_data (self, "compare-messages",
 	                              (GCallback) compare_messages_ignore_parameter_values_cb,
 	                              g_strdupv ((gchar **) parameter_names),
-	                              (GClosureNotify) g_strfreev,
+	                              parameter_names_closure_notify,
 	                              0  /* connect flags */);
 }
 
